"use strict";
const migration_1 = require('./migration');
const git_1 = require('./git');
const url_1 = require('url');
class DbAdapter {
    rowToTask(row) {
        const task = new migration_1.Task({
            id: row['id'],
            type: row['type'],
            appliedAt: row['applied_at'],
            commit: new git_1.Commit({
                sha1: row['commit']
            }),
            head: new git_1.Commit({
                sha1: row['head']
            }),
            migration: new migration_1.Migration({
                name: row['name']
            })
        });
        return task;
    }
}
exports.DbAdapter = DbAdapter;
const postgres_1 = require('./adapters/postgres');
function createAdapterFromUrl(url) {
    const dialect = url_1.parse(url).protocol;
    switch (dialect) {
        case 'postgres:': return new postgres_1.PostgresAdapter(url, require(process.cwd() + '/node_modules/pg'));
        case null: throw new Error('Invalid connection URL ' + url);
        default: throw new Error('Unssuported dialect ' + dialect);
    }
}
exports.createAdapterFromUrl = createAdapterFromUrl;
//# sourceMappingURL=adapter.js.map