import { Commit, CommitSequence } from './git';
import { DbAdapter } from './adapter';
import { TaskType, Task } from './migration';
export declare class Status {
    /** The last migration task that was executed, according to the merkel metadata table */
    lastTask: Task;
    /** The current HEAD commit of the repository */
    head: Commit;
    /** New commits since the last migration */
    newCommits: CommitSequence;
    /** Executes all tasks for newCommits */
    executePendingTasks(migrationDir: string, adapter: DbAdapter, logger?: Logger): Promise<void>;
    /** Returns a string that can be printed to a CLI */
    toString(): string;
}
export declare function getStatus(adapter: DbAdapter, head: Commit, migrationDir: string): Promise<Status>;
export interface Logger {
    log(msg: string): void;
    error(msg: string): void;
    warn(msg: string): void;
}
export interface GenerateOptions {
    migrationDir: string;
    name?: string;
    template?: string;
}
export interface MerkelConfiguration {
    migrationDir: string;
    migrationOutDir: string;
}
export declare function isMerkelRepository(): Promise<boolean>;
export declare function createMigrationDir(migrationDir: string): Promise<void>;
export declare function createConfig(config: MerkelConfiguration): Promise<void>;
export declare function migrate(type: TaskType, migrationDir: string, adapter: DbAdapter, migrations: string[], logger?: Logger): Promise<void>;
export declare function prepareCommitMsg(msgfile: string, migrationDir: string, logger?: Logger): Promise<void>;
export declare function generate(options: GenerateOptions, logger?: Logger): Promise<void>;
